@@ -32,6 +32,42 @@ except ImportError:
 
 from ansible import constants
 from ansible.plugins import action
+import six
+
+DOCUMENTATION = '''
+---
+module: merge_yaml
+short_description: Merge yaml-style configs
+description:
+     - PyYAML is used to merge several yaml files into one
+options:
+  dest:
+    description:
+      - The destination file name
+    required: True
+    type: str
+  sources:
+    description:
+      - A list of files on the destination node to merge together
+    default: None
+    required: True
+    type: str
+author: Sean Mooney
+'''
+
+EXAMPLES = '''
+Merge multiple yaml files:
+
+- hosts: localhost
+  tasks:
+    - name: Merge yaml files
+      merge_yaml:
+        sources:
+          - "/tmp/default.yml"
+          - "/tmp/override.yml"
+        dest:
+          - "/tmp/out.yml"
+'''
 
 
 class ActionModule(action.ActionBase):
@@ -76,7 +112,7 @@ class ActionModule(action.ActionBase):
         if not isinstance(sources, list):
             sources = [sources]
         for source in sources:
-            output.update(self.read_config(source))
+            Utils.update_nested_conf(output, self.read_config(source))
 
         # restore original vars
         self._templar.set_available_variables(old_vars)
@@ -109,3 +145,14 @@ class ActionModule(action.ActionBase):
         finally:
             shutil.rmtree(local_tempdir)
         return result
+
+
+class Utils(object):
+    @staticmethod
+    def update_nested_conf(conf, update):
+        for k, v in six.iteritems(update):
+            if isinstance(v, dict):
+                conf[k] = Utils.update_nested_conf(conf.get(k, {}), v)
+            else:
+                conf[k] = v
+        return conf
