@@ -37,15 +37,13 @@ copy_logs() {
     ps -eo user,pid,ppid,lwp,%cpu,%mem,size,rss,cmd > ${LOG_DIR}/system_logs/ps.txt
 
     # docker related information
-    (docker info && docker images && docker ps -a) > ${LOG_DIR}/system_logs/docker-info.txt
+    (docker info && docker images && docker ps -a && docker network ls) > ${LOG_DIR}/system_logs/docker-info.txt
 
     # ceph related logs
     if [[ $(docker ps --filter name=ceph_mon --format "{{.Names}}") ]]; then
-        docker exec ceph_mon ceph --connect-timeout 5 -s > ${LOG_DIR}/kolla/ceph/ceph_s.txt
-        # NOTE(yoctozepto): osd df removed on purpose to avoid CI POST_FAILURE due to a possible hang:
-        # as of ceph mimic it hangs when MON is operational but MGR not
-        # its usefulness is mediocre and having POST_FAILUREs is bad
-        docker exec ceph_mon ceph --connect-timeout 5 osd tree > ${LOG_DIR}/kolla/ceph/ceph_osd_tree.txt
+        docker exec ceph_mon ceph -s > ${LOG_DIR}/kolla/ceph/ceph_s.txt
+        docker exec ceph_mon ceph osd df > ${LOG_DIR}/kolla/ceph/ceph_osd_df.txt
+        docker exec ceph_mon ceph osd tree > ${LOG_DIR}/kolla/ceph/ceph_osd_tree.txt
     fi
 
     # bifrost related logs
@@ -58,8 +56,14 @@ copy_logs() {
         docker exec bifrost_deploy journalctl -u rabbitmq-server > ${LOG_DIR}/kolla/rabbitmq-server/rabbitmq.txt
     fi
 
+    # haproxy related logs
+    if [[ $(docker ps --filter name=haproxy --format "{{.Names}}") ]]; then
+        mkdir -p ${LOG_DIR}/kolla/haproxy
+        docker exec haproxy bash -c 'echo show stat | socat stdio /var/lib/kolla/haproxy/haproxy.sock' > ${LOG_DIR}/kolla/haproxy/stats.txt
+    fi
+
     for container in $(docker ps -a --format "{{.Names}}"); do
-        docker logs --tail all ${container} > ${LOG_DIR}/docker_logs/${container}.txt
+        docker logs --tail all ${container} &> ${LOG_DIR}/docker_logs/${container}.txt
     done
 
     # Rename files to .txt; this is so that when displayed via
@@ -73,6 +77,8 @@ copy_logs() {
     done
 
     chmod -R 777 ${LOG_DIR}
+    find ${LOG_DIR}/{system_logs,kolla,docker_logs} -iname '*.txt' -execdir gzip -f -9 {} \+
+    find ${LOG_DIR}/{system_logs,kolla,docker_logs} -iname '*.json' -execdir gzip -f -9 {} \+
 }
 
 copy_logs
